@@ -473,6 +473,39 @@ cv::Mat CompressedDepthCodec::toInvDepth(const cv::Mat& depthImg, double depth_m
   return invDepthImg;
 }
 
+ImageTransportCodec::GetCompressedContentResult CompressedDepthCodec::getCompressedImageContent(
+  const topic_tools::ShapeShifter& compressed, const std::string& matchFormat) const
+{
+  sensor_msgs::CompressedImageConstPtr compressedImage;
+  try
+  {
+    compressedImage = compressed.instantiate<sensor_msgs::CompressedImage>();
+  }
+  catch (const ros::Exception& e)
+  {
+    return cras::make_unexpected(cras::format("Invalid shapeshifter passed to compressedDepth decoder: %s.", e.what()));
+  }
+  return this->getCompressedImageContent(*compressedImage, matchFormat);
+}
+
+ImageTransportCodec::GetCompressedContentResult CompressedDepthCodec::getCompressedImageContent(
+  const sensor_msgs::CompressedImage& compressed, const std::string& matchFormat) const
+{
+  const auto format = parseCompressedDepthTransportFormat(compressed.format);
+  if (!format)
+    return cras::make_unexpected("Invalid compressedDepth format: " + format.error());
+
+  if (!matchFormat.empty() && cras::toLower(format->formatString) != cras::toLower(matchFormat))
+    return cras::nullopt;
+
+  const auto headerLen = sizeof(compressed_depth_image_transport::ConfigHeader);
+
+  if (compressed.data.size() < headerLen)
+    return cras::nullopt;
+
+  return CompressedImageContent{format->formatString, {compressed.data.begin() + headerLen, compressed.data.end()}};
+}
+
 void CompressedDepthCodec::encodeRVL(const cv::Mat& depthImg16UC1, std::vector<uint8_t>& compressed) const
 {
   int numPixels = depthImg16UC1.rows * depthImg16UC1.cols;
